use Test::More tests => 1;

BEGIN {
    use_ok('WebService::Pathtraq::API::NormalizeURL');
}

diag( "Testing WebService::Pathtraq::API::NormalizeURL $WebService::Pathtraq::API::NormalizeURL::VERSION" );
